@@ -180,7 +180,8 @@ public:
 private:
     QHash<QPair<Kirigami::PlatformTheme::ColorSet, QPalette::ColorGroup>, Colors> m_cache;
 };
-Q_GLOBAL_STATIC_WITH_ARGS(QScopedPointer<StyleSingleton>, s_style, (new StyleSingleton))
+
+Q_GLOBAL_STATIC(StyleSingleton, s_style);
 
 PlasmaDesktopTheme::PlasmaDesktopTheme(QObject *parent)
     : PlatformTheme(parent)
@@ -194,10 +195,10 @@ PlasmaDesktopTheme::PlasmaDesktopTheme(QObject *parent)
         connect(parentItem, &QQuickItem::windowChanged, this, &PlasmaDesktopTheme::syncWindow);
     }
 
-    (*s_style)->watchers.append(this);
+    s_style->watchers.append(this);
 
     setDefaultFont(qGuiApp->font());
-    setSmallFont((*s_style)->smallFont);
+    setSmallFont(s_style->smallFont);
 
     syncWindow();
     if (!m_window) {
@@ -207,7 +208,7 @@ PlasmaDesktopTheme::PlasmaDesktopTheme(QObject *parent)
 
 PlasmaDesktopTheme::~PlasmaDesktopTheme()
 {
-    (*s_style)->watchers.removeOne(this);
+    s_style->watchers.removeOne(this);
 }
 
 void PlasmaDesktopTheme::syncWindow()
@@ -227,7 +228,7 @@ void PlasmaDesktopTheme::syncWindow()
             window = qw;
         }
         if (qw) {
-            connect(qw, &QQuickWindow::sceneGraphInitialized, this, &PlasmaDesktopTheme::syncWindow);
+            connect(qw, &QQuickWindow::sceneGraphInitialized, this, &PlasmaDesktopTheme::syncWindow, Qt::UniqueConnection);
         }
     }
     m_window = window;
@@ -251,6 +252,10 @@ QIcon PlasmaDesktopTheme::iconFromTheme(const QString &name, const QColor &custo
 
 void PlasmaDesktopTheme::syncColors()
 {
+    if (QCoreApplication::closingDown()) {
+        return;
+    }
+
     QPalette::ColorGroup group = (QPalette::ColorGroup)colorGroup();
     auto parentItem = qobject_cast<QQuickItem *>(parent());
     if (parentItem) {
@@ -268,7 +273,7 @@ void PlasmaDesktopTheme::syncColors()
         }
     }
 
-    const auto colors = (*s_style)->loadColors(colorSet(), group);
+    const auto colors = s_style->loadColors(colorSet(), group);
 
     // foreground
     setTextColor(colors.scheme.foreground(KColorScheme::NormalText).color());
@@ -314,4 +319,5 @@ bool PlasmaDesktopTheme::event(QEvent *event)
     return PlatformTheme::event(event);
 }
 
+#include "moc_plasmadesktoptheme.cpp"
 #include "plasmadesktoptheme.moc"
